@@ -40,7 +40,7 @@ class Provide:
         if self.use_cache:
             self.value = value
 
-        return value  # noqa: R504
+        return value
 
     def __eq__(self, other: Any) -> bool:
         # check if memory address is identical, otherwise compare attributes
