@@ -1,3 +1,3 @@
 from starlite.middleware.compression.base import CompressionMiddleware
 
-__all__ = ["CompressionMiddleware"]
+__all__ = ("CompressionMiddleware",)
